/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration DSPIC :
    
    MCU             : P33EP512MU810
    Dev. Board      : EasyPIC Fusion v7
    SW              : mikroC PRO for dsPIC v7.0.1

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/

sbit MUX_A0_PIN at RC1_bit;
sbit MUX_A0_PIN_Direction at TRISC1_bit;

sbit BUCK_ENABLE_PIN at RC2_bit;
sbit BUCK_ENABLE_PIN_Direction at TRISC2_bit;

sbit MUX_A1_PIN at RD0_bit;
sbit MUX_A1_PIN_Direction at TRISD0_bit;

sbit PG_PIN at RE8_bit;
sbit PG_PIN_Direction at TRISE8_bit;

void systemInit()
{
  PLLPRE_0_bit = 0;
  PLLPRE_1_bit = 0;
  PLLPRE_2_bit = 0;
  PLLPRE_3_bit = 0;
  PLLPRE_4_bit = 0;

  PLLFBD = 38;             // PLL multiplier M=38

  PLLPOST_0_bit = 0;
  PLLPOST_1_bit = 0;

  ANSELA = 0x00;    // Convert all I/O pins to digital
  ANSELB = 0x00;
  ANSELC = 0x00;
  ANSELD = 0x00;
  ANSELE = 0x00;
  ANSELG = 0x00;
  UART1_Init(9600);

}

void Buck_Init()
{
    MUX_A0_PIN_Direction = 0;
    asm nop
    BUCK_ENABLE_PIN_Direction = 0;
    asm nop
    MUX_A1_PIN_Direction = 0;
    asm nop
    PG_PIN_Direction = 1;
    asm nop
    BUCK_ENABLE_PIN = 1;
    asm nop
    MUX_A0_PIN = 0;
    asm nop
    MUX_A1_PIN = 0;
    asm nop
}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART1_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART1_Write_Text( "\r\n" );
        delay_ms(1000);
    }

}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
    	Buck_Task();
    }
}